summaryrefslogtreecommitdiff
path: root/ace/Singleton.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-10-04 17:12:45 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-10-04 17:12:45 +0000
commita664b03104413dbcf885a6b64b34989ec747491d (patch)
treedb5505b55d7cdbaa5ce8771e5e947b4e05a0876d /ace/Singleton.h
parent9beb73949f9eb59c74460374b4035bfbd6817bcf (diff)
downloadATCD-a664b03104413dbcf885a6b64b34989ec747491d.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Singleton.h')
-rw-r--r--ace/Singleton.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/ace/Singleton.h b/ace/Singleton.h
index e186923fb26..1f0b57f1a47 100644
--- a/ace/Singleton.h
+++ b/ace/Singleton.h
@@ -22,7 +22,7 @@
#include "ace/Synch.h"
-template <class TYPE, class LOCK>
+template <class TYPE, class ACE_LOCK>
class ACE_Singleton : public ACE_Cleanup
// = TITLE
// A Singleton Adapter the uses the Adapter pattern to turn
@@ -32,7 +32,7 @@ class ACE_Singleton : public ACE_Cleanup
// = DESCRIPTION
// This implementation is a slight variation on the GoF
// Singleton pattern. In particular, a single
// <ACE_Singleton<TYPE, LOCK> > instance is allocated here, not
// a <TYPE> instance. The reason for this is to allow
// registration with the <ACE_Object_Manager>, so that the
// Singleton can be cleaned up when the process exits. For this
@@ -59,21 +59,21 @@ protected:
// Contained instance.
#if !defined (ACE_LACKS_STATIC_DATA_MEMBER_TEMPLATES)
- static ACE_Singleton<TYPE, LOCK> *singleton_;
+ static ACE_Singleton<TYPE, ACE_LOCK> *singleton_;
// Pointer to the Singleton (ACE_Cleanup) instance.
static LOCK ace_singleton_lock_;
// Lock the creation of the singleton.
#endif /* ACE_LACKS_STATIC_DATA_MEMBER_TEMPLATES */
- static ACE_Singleton<TYPE, LOCK> *&instance_i (void);
+ static ACE_Singleton<TYPE, ACE_LOCK> *&instance_i (void);
// Get pointer to the Singleton instance.
static LOCK &singleton_lock_i (void);
// Get reference to Singleton lock.
};
-template <class TYPE, class LOCK>
+template <class TYPE, class ACE_LOCK>
class ACE_TSS_Singleton : public ACE_Cleanup
// = TITLE
// This class uses the Adapter pattern to turn ordinary classes
@@ -111,7 +111,7 @@ protected:
// Contained instance.
#if !defined (ACE_LACKS_STATIC_DATA_MEMBER_TEMPLATES)
- static ACE_TSS_Singleton<TYPE, LOCK> *singleton_;
+ static ACE_TSS_Singleton<TYPE, ACE_LOCK> *singleton_;
// Pointer to the Singleton (ACE_Cleanup) instance.
static LOCK ace_singleton_lock_;
@@ -32,7 +32,7 @@ class ACE_Singleton : public ACE_Cleanup
// This implementation is a slight variation on the GoF
// Singleton pattern. In particular, a single
- // <ACE_Singleton<TYPE, LOCK> > instance is allocated here, not
+ // <ACE_Singleton<TYPE, ACE_LOCK> > instance is allocated here, not
// a <TYPE> instance. The reason for this is to allow
// registration with the <ACE_Object_Manager>, so that the